# Changelog

## 1.4.5 (2022-10-25)
- Support wheels for Python 3.11
- Upgrade vendored ffmpeg to 5.1.2
- Use setuptools_scm instead of bump2version

## 1.4.4 (2022-02-16)
- Support wheels for Python 3.10

## 1.4.3 (2021-10-15)
- Fix distribution
- Setup pre-commit.ci

For older changelogs see the [Github releases](https://github.com/pupil-labs/pyndsi/releases?after=v1.4.1).
